==> esp8266-0.3.0.crate: esp8266-0.3.0/src/timer/frc2_count.rs <==
#[doc = "Register `FRC2_COUNT` reader"]
pub struct R(crate::R<FRC2_COUNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_COUNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<FRC2_COUNT_SPEC>> for R {
    fn from(reader: crate::R<FRC2_COUNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `frc2_count` reader - the current value of the counter. It is a increasingcounter."]
pub struct FRC2_COUNT_R(crate::FieldReader<u32, u32>);
impl FRC2_COUNT_R {
    pub(crate) fn new(bits: u32) -> Self {
        FRC2_COUNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_COUNT_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - the current value of the counter. It is a increasingcounter."]
    #[inline(always)]
    pub fn frc2_count(&self) -> FRC2_COUNT_R {
        FRC2_COUNT_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
#[doc = "the current value of the counter. It is a increasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_count](index.html) module"]
pub struct FRC2_COUNT_SPEC;
impl crate::RegisterSpec for FRC2_COUNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_count::R](R) reader structure"]
impl crate::Readable for FRC2_COUNT_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets FRC2_COUNT to value 0"]
impl crate::Resettable for FRC2_COUNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/timer/frc2_count.rs <==
#[doc = "Register `FRC2_COUNT` reader"]
pub struct R(crate::R<FRC2_COUNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_COUNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FRC2_COUNT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FRC2_COUNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `frc2_count` reader - the current value of the counter. It is a increasingcounter."]
pub struct FRC2_COUNT_R(crate::FieldReader<u32, u32>);
impl FRC2_COUNT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        FRC2_COUNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_COUNT_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - the current value of the counter. It is a increasingcounter."]
    #[inline(always)]
    pub fn frc2_count(&self) -> FRC2_COUNT_R {
        FRC2_COUNT_R::new(self.bits as u32)
    }
}
#[doc = "the current value of the counter. It is a increasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_count](index.html) module"]
pub struct FRC2_COUNT_SPEC;
impl crate::RegisterSpec for FRC2_COUNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_count::R](R) reader structure"]
impl crate::Readable for FRC2_COUNT_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets FRC2_COUNT to value 0"]
impl crate::Resettable for FRC2_COUNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
